'use client'

import React, { useEffect, useRef } from 'react'
import { motion, useAnimation } from 'framer-motion'
import { useInView } from 'react-intersection-observer'

interface SectionProps {
  title: string
  content: string
}

const SectionCard: React.FC<SectionProps> = ({ title, content }) => {
  return (
    <motion.div 
      className="mvs-card bg-white p-6 rounded-lg shadow-md"
      whileHover={{ scale: 1.05 }}
      transition={{ duration: 0.3 }}
    >
      <div className="mvs-card-header flex items-center mb-4">
        <div className="mvs-icon w-8 h-8 bg-orange-500 rounded-full mr-4"></div>
        <h3 className="mvs-card-title text-xl font-bold">{title}</h3>
      </div>
      <p className="mvs-card-content text-gray-600">{content}</p>
    </motion.div>
  )
}

const MissionVisionSection: React.FC = () => {
  const controls = useAnimation()
  const [ref, inView] = useInView({
    triggerOnce: true,
    threshold: 0.1,
  })

  useEffect(() => {
    if (inView) {
      controls.start('visible')
    }
  }, [controls, inView])

  const containerVariants = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2
      }
    }
  }

  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.5 }
    }
  }

  const sectionData = [
    {
      title: "Mission",
      content: "Comfort produce husband boy her had hearing. Law others theirs passed but wishes. You day real less till dear read. Considered use dispatched melancholy sympathize discretion led."
    },
    {
      title: "Vision",
      content: "Comfort produce husband boy her had hearing. Law others theirs passed but wishes. You day real less till dear read. Considered use dispatched melancholy sympathize discretion led."
    },
    {
      title: "History",
      content: "Comfort produce husband boy her had hearing. Law others theirs passed but wishes. You day real less till dear read. Considered use dispatched melancholy sympathize discretion led."
    },
    {
      title: "Our Team",
      content: "Comfort produce husband boy her had hearing. Law others theirs passed but wishes. You day real less till dear read. Considered use dispatched melancholy sympathize discretion led."
    }
  ]

  return (
    <section ref={ref} className="mvs-section bg-gray-100 py-16 px-4">
      <div className="mvs-container max-w-6xl mx-auto">
        <motion.h2 
          className="mvs-main-title text-4xl font-bold text-center mb-12"
          initial={{ opacity: 0, y: -20 }}
          animate={controls}
          variants={itemVariants}
        >
          Mission, Vision & History
        </motion.h2>
        <motion.div 
          className="mvs-grid grid grid-cols-1 md:grid-cols-2 gap-8"
          variants={containerVariants}
          initial="hidden"
          animate={controls}
        >
          {sectionData.map((section, index) => (
            <motion.div key={index} variants={itemVariants}>
              <SectionCard title={section.title} content={section.content} />
            </motion.div>
          ))}
        </motion.div>
      </div>
    </section>
  )
}

export default MissionVisionSection